@@ -78,7 +78,7 @@ class NodesController(RestController):
                     node_response['nodes'].append(node)
 
             else:
-                node_response = session.query(
+                node = session.query(
                     Node.id, Node.address, Node.port, Node.status, Node.enabled
                 ).join(LoadBalancer.nodes).\
                     filter(LoadBalancer.tenantid == tenant_id).\
@@ -86,14 +86,23 @@ class NodesController(RestController):
                     filter(Node.id == node_id).\
                     first()
 
-            if node_response is None:
-                session.rollback()
-                response.status = 400
-                return dict(message='Bad Request', details='node not found')
-            else:
-                session.commit()
-                response.status = 200
-                return node_response
+                if node is None:
+                    session.rollback()
+                    response.status = 400
+                    return dict(
+                        message='Bad Request', details='node not found'
+                    )
+
+                node_response = node._asdict()
+                if node_response['enabled'] == 1:
+                    node_response['condition'] = 'ENABLED'
+                else:
+                    node_response['condition'] = 'DISABLED'
+                del node_response['enabled']
+
+            session.commit()
+            response.status = 200
+            return node_response
 
     @wsme_pecan.wsexpose(LBNodeResp, body=LBNodePost, status_code=202)
     def post(self, body=None):
@@ -235,8 +244,8 @@ class NodesController(RestController):
             )
             return ''
 
-    @expose('json')
-    def delete(self, node_id):
+    @wsme_pecan.wsexpose(None)
+    def delete(self, status_code=202):
         """Remove a node from the load balancer.
 
         :param load_balancer_id: id of lb
@@ -247,38 +256,29 @@ class NodesController(RestController):
 
         Returns: None
         """
+        node_id = self.nodeid
         tenant_id = get_limited_to_project(request.headers)
         if self.lbid is None:
-            response.status = 400
-            return dict(
-                message="Bad Request",
-                details='Load Balancer ID has not been supplied'
-            )
+            raise ClientSideError('Load Balancer ID has not been supplied')
 
         tenant_id = get_limited_to_project(request.headers)
         with db_session() as session:
             load_balancer = session.query(LoadBalancer).\
                 filter(LoadBalancer.tenantid == tenant_id).\
                 filter(LoadBalancer.id == self.lbid).\
-                filter(LoadBalancer.device != 'DELETED').\
+                filter(LoadBalancer.status != 'DELETED').\
                 first()
             if load_balancer is None:
                 session.rollback()
-                response.status = 400
-                return dict(
-                    message="Bad Request",
-                    details="Load Balancer not found"
-                )
+                raise ClientSideError("Load Balancer not found")
             load_balancer.status = 'PENDING_UPDATE'
             nodecount = session.query(Node).\
                 filter(Node.lbid == self.lbid).count()
             # Can't delete the last LB
             if nodecount <= 1:
                 session.rollback()
-                response.status = 400
-                return dict(
-                    message="Bad Request",
-                    details="Cannot delete the last node in a load balancer"
+                raise ClientSideError(
+                    "Cannot delete the last node in a load balancer"
                 )
             node = session.query(Node).\
                 filter(Node.lbid == self.lbid).\
@@ -286,10 +286,8 @@ class NodesController(RestController):
                 first()
             if not node:
                 session.rollback()
-                response.status = 400
-                return dict(
-                    message="Bad Request",
-                    details="Node not found in supplied Load Balancer"
+                raise ClientSideError(
+                    "Node not found in supplied Load Balancer"
                 )
             session.delete(node)
             device = session.query(
@@ -301,7 +299,6 @@ class NodesController(RestController):
             submit_job(
                 'UPDATE', device.name, device.id, self.lbid
             )
-            response.status = 202
             return None
 
     @expose('json')
